<!DOCTYPE html>
<!--
 Copyright European Organization for Nuclear Research (CERN)

 Licensed under the Apache License, Version 2.0 (the "License");
 You may not use this file except in compliance with the License.
 You may obtain a copy of the License at
 http://www.apache.org/licenses/LICENSE-2.0

 Authors:
 - Mario Lassnig, <mario.lassnig@cern.ch>, 2014
 - Thomas Beermann, <thomas.beermann@cern.ch>, 2014-2020
 - Benedikt Ziemons <benedikt.ziemons@cern.ch>, 2020
-->

<html>
  <head>
    <title>Rucio UI - Problem</title>
    <link rel="shortcut icon" href="/media/favicon.ico" type="image/x-icon">
    <link rel="icon" href="/media/favicon.ico" type="image/x-icon">
    <link rel="stylesheet" type="text/css" href="/static/rucio.css">
  </head>
  <body>
    <div>{{ msg }}</div>
  </body>
</html>
