
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.25.0',
    'branch_nick': 'patch-0-Release__1_25_0_preparation',
    'revision_id': '253c2f12f6e99e5eca5f59c6538e5a2bcd5f7c48',
    'revno': 10443
}
